FrameRateInfo class

Constructors

FrameRateInfo({required double productionFps, required double displayFps, required double stage1Ms, required double stage2Ms, required double renderMs, required double totalFrameMs, required double idleMs, required double cpuUsagePercent, required double frameP95Ms, required double frameP99Ms, required double jankRatio50Ms})
const
FrameRateInfo.fromJson(Map<String, dynamic> json)
factory

Properties

cpuUsagePercent double
final
displayFps double
final
frameP95Ms double
final
frameP99Ms double
final
hashCode int
The hash code for this object.
no setterinherited
idleMs double
final
jankRatio50Ms double
final
productionFps double
final
renderMs double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stage1Ms double
final
stage2Ms double
final
totalFrameMs double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited